@@ -193,6 +193,10 @@ long pth_ctrl(unsigned long query, ...)
         FILE *fp = va_arg(ap, FILE *);
         pth_dumpstate(fp);
     }
+    else if (query & PTH_CTRL_FAVOURNEW) {
+        int favournew = va_arg(ap, int);
+        pth_favournew = (favournew ? 1 : 0);
+    }
     else
         rc = -1;
     va_end(ap);
