@@ -97,8 +97,9 @@ pth_msgport_t pth_msgport_find(const char *name)
     /* iterate over message ports */
     mp = mpf = (pth_msgport_t)pth_ring_first(&pth_msgport);
     while (mp != NULL) {
-        if (strcmp(mp->mp_name, name) == 0)
-            break;
+        if (mp->mp_name != NULL)
+            if (strcmp(mp->mp_name, name) == 0)
+                break;
         mp = (pth_msgport_t)pth_ring_next(&pth_msgport, (pth_ringnode_t *)mp);
         if (mp == mpf) {
             mp = NULL;
@@ -108,7 +109,7 @@ pth_msgport_t pth_msgport_find(const char *name)
     return mp;
 }
 
-/* number of message on a port */
+/* number of messages on a port */
 int pth_msgport_pending(pth_msgport_t mp)
 {
     if (mp == NULL)
